print qq~

IniConf.pm is going away, and will be replaced with
Config::IniFiles. Please get that instead. There are
a number of bug fixes, cool new features, and, even
more important, it's the one that will have future
bugs fixed!

http://dev.rcbowen.com/iniconf/

~;

